# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2017-11-09 16:03
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cmsplugin_rototalc', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='carouselplugin',
            name='initial_slide',
            field=models.SmallIntegerField(default=0, help_text='Slide to start on.', verbose_name='initial slide'),
        ),
    ]



from cms.models import CMSPlugin

from django.db import models
from django.utils.translation import ugettext_lazy as _


class CarouselPlugin(CMSPlugin):
    """A carousel"""

    # VERTICAL = True
    # HORIZONTAL = False
    # VERTICAL_CHOICES = (
    #     (HORIZONTAL, _('Horizontal')),
    #     (VERTICAL, _('Vertical'))
    # )

    name = models.SlugField(
        _('name'),
        max_length=30,
        unique=False,  # django-cms keeps two copies
        blank=False,
        null=False
    )

    show_arrows = models.BooleanField(
        _('show arrows'),
        default=True,
        help_text=_('Enable Next/Prev arrows.')
    )

    autoplay = models.BooleanField(
        _('autoplay'),
        default=True,
        help_text=_('Enable auto play of slides.')
    )

    autoplay_speed = models.SmallIntegerField(
        _('autoplay speed'),
        default=3000,
        help_text=_('Auto play change interval (in milliseconds).')
    )

    slides_to_show = models.SmallIntegerField(
        _('slides to show'),
        default=1,
        help_text=_('Number of slides to show at a time.')
    )

    initial_slide = models.SmallIntegerField(
        _('initial slide'),
        default=0,
        help_text=_('Slide to start on.')
    )

    center_mode = models.BooleanField(
        _('center mode'),
        default=True,
        help_text=_(
            'Enable centered view with partial prev/next slides. '
            'Use with odd numbered slidesToShow counts.'
        )
    )

    dots = models.BooleanField(
        _('show dots'),
        default=True,
        help_text=_('Show current slide indicator dots.')
    )

    focus_on_select = models.BooleanField(
        _('focus on select'),
        default=False,
        help_text=_('Enable focus on selected element (click).')
    )

    infinite = models.BooleanField(
        _('infinite'),
        default=True,
        help_text=_('Infinite looping.')
    )

    speed = models.SmallIntegerField(
        _('speed'),
        default=300,
        help_text=_('Transition speed (in milliseconds).')
    )

    # vertical = models.BooleanField(
    #     _('slide direction'),
    #     choices=VERTICAL_CHOICES,
    #     default=HORIZONTAL
    # )

    variable_width = models.BooleanField(
        _('variable width'),
        default=True,
        help_text=_('Variable width slides.')
    )

    height = models.CharField(
        _('height'),
        max_length=10,
        null=False, blank=False,
        help_text=_('CSS size for the carousel height.')
    )

    slide_margin = models.CharField(
        _('slide margin'),
        max_length=10,
        null=False, blank=False,
        help_text=_('CSS size for the margin between slides.')
    )

    def __str__(self):
        return self.name

    class Meta:
        verbose_name = _('Carousel')
        verbose_name_plural = _('Carousels')


class SlidePlugin(CMSPlugin):
    """A generic slide"""

    show_caption = models.BooleanField(
        _('show caption'),
        default=False,
    )

    caption_text = models.CharField(
        _('caption'), max_length=400, default='', blank=True,
    )

    def __str__(self):
        return self.caption_text

    class Meta:
        verbose_name = _('Slide')
        verbose_name_plural = _('Slides')



# -*- coding: utf-8 -*-
# Generated by Django 1.11.10 on 2018-02-22 15:02
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('cmsplugin_rototalc', '0004_carouselplugin_header_alignment'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='carouselplugin',
            name='header_alignment',
        ),
        migrations.RemoveField(
            model_name='carouselplugin',
            name='heading_level',
        ),
        migrations.RemoveField(
            model_name='carouselplugin',
            name='subtitle',
        ),
        migrations.RemoveField(
            model_name='carouselplugin',
            name='title',
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2017-12-13 14:33
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cmsplugin_rototalc', '0003_auto_20171207_1512'),
    ]

    operations = [
        migrations.AddField(
            model_name='carouselplugin',
            name='header_alignment',
            field=models.CharField(blank=True, choices=[('left', 'left'), ('right', 'right'), ('center', 'center')], max_length=10, verbose_name='header alignment'),
        ),
    ]



# -*- coding: utf-8 -*-

from django.apps import AppConfig
from django.utils.translation import ugettext_lazy as _


class RototalcConfig(AppConfig):
    name = 'ripiu.cmsplugin_rototalc'
    verbose_name = _('Carousel')



from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from django.utils.translation import ugettext_lazy as _

from .models import SlidePlugin, CarouselPlugin


def js_boolean(prop):
    return 'true' if prop else 'false'


@plugin_pool.register_plugin
class CarouselPluginPublisher(CMSPluginBase):
    model = CarouselPlugin
    name = _('Carousel')
    module = 'Ri+'
    render_template = 'ripiu/cmsplugin_rototalc/carousel.html'
    allow_children = True
    child_classes = ['SlidePluginPublisher']
    fieldsets = (
        (_('Slick configuration'), {
            'fields': (
                ('show_arrows', 'dots', 'autoplay'),
                ('autoplay_speed', 'speed'),
                ('slides_to_show', 'initial_slide'),
                ('center_mode', 'focus_on_select'),
                ('infinite', 'variable_width'),
            )
        }),
    )

    def render(self, context, instance, placeholder):
        import json
        context = super(CarouselPluginPublisher, self).render(
            context, instance, placeholder
        )
        slick_conf = {
            'autoplay': instance.autoplay,
            'autoplaySpeed': instance.autoplay_speed,
            'arrows': instance.show_arrows,
            'centerMode': instance.center_mode,
            'dots': instance.dots,
            'infinite': instance.infinite,
            'speed': instance.speed,
            'vertical': False,  # instance.vertical,
            'slidesToShow': instance.slides_to_show,
            'initialSlide': instance.initial_slide,
            'focusOnSelect': instance.focus_on_select,
            'variableWidth': instance.variable_width,
            'cssEase': 'ease',
            'useCSS': True,
        }
        context.update({
            'instance': instance,
            'placeholder': placeholder,
            'conf': json.dumps(slick_conf),
        })
        return context


@plugin_pool.register_plugin
class SlidePluginPublisher(CMSPluginBase):
    model = SlidePlugin
    name = _('Slide')
    module = 'Ri+'
    render_template = 'ripiu/cmsplugin_rototalc/slide.html'
    allow_children = True
    parent_classes = ['CarouselPluginPublisher']
    require_parent = True

    def render(self, context, instance, placeholder):
        context = super(SlidePluginPublisher, self).render(
            context, instance, placeholder
        )
        carousel = instance.parent.get_bound_plugin()
        context.update({
            'instance': instance,
            'placeholder': placeholder,
            'slider_height': carousel.height,
            'horizontal_margin': carousel.slide_margin,
        })
        return context



from setuptools import setup

from ripiu.cmsplugin_rototalc import __version__

setup(
    name='ripiu.cmsplugin_rototalc',
    version=__version__,
    url='https://github.com/ripiu/cmsplugin_rototalc',
    license='BSD-new',
    description='A plugin for Django-CMS to display galleries, '
                'based on Slick carousel',
    long_description=open('README.rst').read(),
    author='matteo vezzola',
    author_email='matteo@studioripiu.it',
    # find_packages doesn't like implicit namespace packages:
    # https://stackoverflow.com/questions/27047443/
    # packages=find_packages(),
    packages=['ripiu.cmsplugin_rototalc'],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
    # TODO: check requirements
    install_requires=[
        'Django >= 1.8',
        'django-cms >= 3.1',
        'django-sekizai >= 0.4.2',
        'django-appconf',
    ],
    python_requires='>=3.3',
    include_package_data=True,
    zip_safe=False,
)



# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2017-11-09 14:44
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('cms', '0016_auto_20160608_1535'),
    ]

    operations = [
        migrations.CreateModel(
            name='CarouselPlugin',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='cmsplugin_rototalc_carouselplugin', serialize=False, to='cms.CMSPlugin')),
                ('name', models.SlugField(max_length=30, verbose_name='name')),
                ('show_arrows', models.BooleanField(default=True, help_text='Enable Next/Prev arrows.', verbose_name='show arrows')),
                ('autoplay', models.BooleanField(default=True, help_text='Enable auto play of slides.', verbose_name='autoplay')),
                ('autoplay_speed', models.SmallIntegerField(default=3000, help_text='Auto play change interval (in milliseconds).', verbose_name='autoplay speed')),
                ('slides_to_show', models.SmallIntegerField(default=1, help_text='Number of slides to show at a time.', verbose_name='slides to show')),
                ('center_mode', models.BooleanField(default=True, help_text='Enable centered view with partial prev/next slides. Use with odd numbered slidesToShow counts.', verbose_name='center mode')),
                ('dots', models.BooleanField(default=True, help_text='Show current slide indicator dots.', verbose_name='show dots')),
                ('focus_on_select', models.BooleanField(default=False, help_text='Enable focus on selected element (click).', verbose_name='focus on select')),
                ('infinite', models.BooleanField(default=True, help_text='Infinite looping.', verbose_name='infinite')),
                ('speed', models.SmallIntegerField(default=300, help_text='Transition speed (in milliseconds).', verbose_name='speed')),
                ('variable_width', models.BooleanField(default=True, help_text='Variable width slides.', verbose_name='variable width')),
                ('height', models.CharField(help_text='CSS size for the carousel height.', max_length=10, verbose_name='height')),
                ('slide_margin', models.CharField(help_text='CSS size for the margin between slides.', max_length=10, verbose_name='slide margin')),
            ],
            options={
                'verbose_name': 'Carousel',
                'verbose_name_plural': 'Carousels',
            },
            bases=('cms.cmsplugin',),
        ),
        migrations.CreateModel(
            name='SlidePlugin',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='cmsplugin_rototalc_slideplugin', serialize=False, to='cms.CMSPlugin')),
                ('show_caption', models.BooleanField(default=False, verbose_name='show caption')),
                ('caption_text', models.CharField(blank=True, default='', max_length=400, verbose_name='caption')),
            ],
            options={
                'verbose_name': 'Slide',
                'verbose_name_plural': 'Slides',
            },
            bases=('cms.cmsplugin',),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2017-12-07 14:12
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cmsplugin_rototalc', '0002_carouselplugin_initial_slide'),
    ]

    operations = [
        migrations.AddField(
            model_name='carouselplugin',
            name='heading_level',
            field=models.PositiveSmallIntegerField(choices=[(1, 'H1'), (2, 'H2'), (3, 'H3'), (4, 'H4'), (5, 'H5'), (6, 'H6')], default=2, help_text='Choose a heading level', verbose_name='heading level'),
        ),
        migrations.AddField(
            model_name='carouselplugin',
            name='subtitle',
            field=models.CharField(blank=True, default='', max_length=400, verbose_name='subtitle'),
        ),
        migrations.AddField(
            model_name='carouselplugin',
            name='title',
            field=models.CharField(blank=True, default='', max_length=400, verbose_name='title'),
        ),
    ]
